Function set_oneshot_timer
pub fn set_oneshot_timer(deadline_ns: u64)Expand description
Set a one-shot timer.
A timer interrupt will be triggered at the specified monotonic time deadline (in nanoseconds).
pub fn set_oneshot_timer(deadline_ns: u64)Set a one-shot timer.
A timer interrupt will be triggered at the specified monotonic time deadline (in nanoseconds).